@@ -1,51 +1,55 @@
 from __future__ import annotations
 
 import io
+import pathlib
 
 import pandas as pd
 import smart_open
-
 from astro import constants
+from astro.airflow.datasets import Dataset
 from astro.files.locations import create_file_location
 from astro.files.locations.base import BaseFileLocation
-from astro.files.types import create_file_type
+from astro.files.types import FileType, create_file_type
+from attr import define, field
 
 
-class File:  # skipcq: PYL-W1641
+@define
+class File(Dataset):
     """
     Handle all file operations, and abstract away the details related to location and file types.
     Intended to be used within library.
+
+    :param path: Path to a file in the filesystem/Object stores
+    :param conn_id: Airflow connection ID
+    :param filetype: constant to provide an explicit file type
+    :param normalize_config: parameters in dict format of pandas json_normalize() function.
     """
 
-    template_fields = ("location",)
+    path: str
+    conn_id: str | None = None
+    filetype: constants.FileType | None = None
+    normalize_config: dict | None = None
 
-    def __init__(
-        self,
-        path: str,
-        conn_id: str | None = None,
-        filetype: constants.FileType | None = None,
-        normalize_config: dict | None = None,
-    ):
-        """Init file object which represent a single file in local/object stores
+    uri: str = field(init=False)
+    extra: dict | None = field(init=False, factory=dict)
 
-        :param path: Path to a file in the filesystem/Object stores
-        :param conn_id: Airflow connection ID
-        :param filetype: constant to provide an explicit file type
-        :param normalize_config: parameters in dict format of pandas json_normalize() function.
-        """
-        self.location: BaseFileLocation = create_file_location(path, conn_id)
-        self.type = create_file_type(
-            path=path, filetype=filetype, normalize_config=normalize_config
+    template_fields = (
+        "path",
+        "conn_id",
+    )
+
+    @property
+    def location(self) -> BaseFileLocation:
+        return create_file_location(self.path, self.conn_id)
+
+    @property
+    def type(self) -> FileType:  # noqa: A003
+        return create_file_type(
+            path=self.path,
+            filetype=self.filetype,
+            normalize_config=self.normalize_config,
         )
 
-    @property
-    def path(self) -> str:
-        return self.location.path
-
-    @property
-    def conn_id(self) -> str | None:
-        return self.location.conn_id
-
     @property
     def size(self) -> int:
         """
@@ -65,6 +69,14 @@ class File:  # skipcq: PYL-W1641
         result: bool = self.type.name == constants.FileType.PARQUET
         return result
 
+    def is_pattern(self) -> bool:
+        """
+        Returns True when file path is a pattern(eg. s3://bucket/folder or /folder/sample_* etc)
+
+        :return: True or False
+        """
+        return not pathlib.PosixPath(self.path).suffix
+
     def create_from_dataframe(self, df: pd.DataFrame) -> None:
         """Create a file in the desired location using the values of a dataframe.
 
@@ -75,18 +87,25 @@ class File:  # skipcq: PYL-W1641
         ) as stream:
             self.type.create_from_dataframe(stream=stream, df=df)
 
+    def export_to_dataframe(self, **kwargs) -> pd.DataFrame:
+        """Read file from all supported location and convert them into dataframes."""
+        mode = "rb" if self.is_binary() else "r"
+        with smart_open.open(
+            self.path, mode=mode, transport_params=self.location.transport_params
+        ) as stream:
+            return self.type.export_to_dataframe(stream, **kwargs)
+
     def _convert_remote_file_to_byte_stream(self) -> io.IOBase:
         """
         Read file from all supported location and convert them into a buffer that can be streamed into other data
         structures.
-
         Due to noted issues with using smart_open with pandas (like
         https://github.com/RaRe-Technologies/smart_open/issues/524), we create a BytesIO or StringIO buffer
-        before exporting to a dataframe. We've found a sizable speed improvement with this optimizat
-
-        Returns: an io object that can be streamed into a dataframe (or other object)
+        before exporting to a dataframe. We've found a sizable speed improvement with this optimization
 
+        :returns: an io object that can be streamed into a dataframe (or other object)
         """
+
         mode = "rb" if self.is_binary() else "r"
         remote_obj_buffer = io.BytesIO() if self.is_binary() else io.StringIO()
         with smart_open.open(
@@ -96,9 +115,8 @@ class File:  # skipcq: PYL-W1641
         remote_obj_buffer.seek(0)
         return remote_obj_buffer
 
-    def export_to_dataframe(self, **kwargs) -> pd.DataFrame:
-        """Read file from all supported location and convert them into dataframes.
-
+    def export_to_dataframe_via_byte_stream(self, **kwargs) -> pd.DataFrame:
+        """Read files from all supported locations and convert them into dataframes.
         Due to noted issues with using smart_open with pandas (like
         https://github.com/RaRe-Technologies/smart_open/issues/524), we create a BytesIO or StringIO buffer
         before exporting to a dataframe. We've found a sizable speed improvement with this optimization.
@@ -113,17 +131,38 @@ class File:  # skipcq: PYL-W1641
         file_exists: bool = self.location.exists()
         return file_exists
 
-    def __repr__(self) -> str:
-        return (
-            f'{self.__class__.__name__}(location="{self.location}",type="{self.type}")'
-        )
-
     def __str__(self) -> str:
-        return self.location.path  # type: ignore
+        return self.path
 
-    def __eq__(self, other):
+    def __eq__(self, other) -> bool:
+        if not isinstance(other, self.__class__):
+            return NotImplemented
         return self.location == other.location and self.type == other.type
 
+    def __hash__(self) -> int:
+        return hash((self.path, self.conn_id, self.filetype))
+
+    @uri.default
+    def _path_to_dataset_uri(self) -> str:
+        """Build a URI to be passed to Dataset obj introduced in Airflow 2.4"""
+        from urllib.parse import urlencode, urlparse
+
+        parsed_url = urlparse(url=self.path)
+        netloc = parsed_url.netloc
+        # Local filepaths do not have scheme
+        parsed_scheme = parsed_url.scheme or "file"
+        scheme = f"astro+{parsed_scheme}"
+        extra = {}
+        if self.filetype:
+            extra["filetype"] = str(self.filetype)
+
+        new_parsed_url = parsed_url._replace(
+            netloc=f"{self.conn_id}@{netloc}" if self.conn_id else netloc,
+            scheme=scheme,
+            query=urlencode(extra),
+        )
+        return new_parsed_url.geturl()
+
 
 def resolve_file_path_pattern(
     path_pattern: str,
