@@ -7,7 +7,6 @@ from pathlib import Path
 from urllib.parse import urlparse
 
 import smart_open
-
 from astro.constants import FileLocation
 
 
@@ -122,12 +121,17 @@ class BaseFileLocation(ABC):
         except OSError:
             return False
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f'{self.__class__.__name__}(path="{self.path}",conn_id="{self.conn_id}")'
 
-    def __str__(self):
+    def __str__(self) -> str:
         """String representation of location"""
         return self.path
 
-    def __eq__(self, other):
+    def __eq__(self, other) -> bool:
+        if not isinstance(other, self.__class__):
+            return NotImplemented
         return self.path == other.path and self.conn_id == other.conn_id
+
+    def __hash__(self) -> int:
+        return hash((self.path, self.conn_id))
