@@ -4,7 +4,6 @@ import io
 import json
 
 import pandas as pd
-
 from astro.constants import DEFAULT_CHUNK_SIZE
 from astro.constants import FileType as FileTypeConstants
 from astro.files.types.base import FileType
@@ -60,24 +59,31 @@ class NDJSONFileType(FileType):
         nrows = kwargs.get("nrows", float("inf"))
         chunksize = kwargs.get("chunksize", DEFAULT_CHUNK_SIZE)
 
-        result_df = None
-        rows = stream.readlines(chunksize)
+        result_df = []
         row_count = 0
-        while len(rows) > 0 and (nrows and row_count < nrows):
+        extra_rows = []
+
+        while nrows and row_count < nrows:
+            extra_rows.extend(stream.readlines(chunksize))
+            rows = extra_rows
+            if len(rows) == 0:
+                break
+
             # Remove extra rows
             if nrows and nrows < row_count + len(rows):
-                diff = (row_count + len(rows)) - nrows
-                rows = rows[: diff + 1]
-
-            df = pd.DataFrame(
-                pd.json_normalize([json.loads(row) for row in rows], **normalize_config)
-            )
-            if result_df is None:
-                result_df = df
+                extra_rows = rows[nrows:]
+                rows = rows[:nrows]
             else:
-                result_df = pd.concat([result_df, df])
+                extra_rows = []
 
-            row_count = result_df.shape[0]
-            rows = stream.readlines(DEFAULT_CHUNK_SIZE)
+            df = pd.json_normalize(
+                [json.loads(row) for row in rows], **normalize_config
+            )
+            result_df.append(df)
 
-        return result_df
+            row_count = row_count + df.shape[0]
+
+        # Running concat multiple times is much slower instead we are appending all the generated dataframes
+        # in a list and then concatenating in single call. This brought down the cost from 351.79550790786743
+        # to 2.3778765201568604.
+        return pd.concat(result_df)
