@@ -3,21 +3,21 @@ from __future__ import annotations
 from typing import Any
 
 from airflow.decorators.base import get_unique_task_id
-from airflow.models import BaseOperator
 from airflow.models.xcom_arg import XComArg
-
 from astro.databases import create_database
-from astro.sql.table import Table
+from astro.sql.operators.base_operator import AstroSQLBaseOperator
+from astro.sql.table import BaseTable
+from astro.utils.typing_compat import Context
 
 
-class DropTableOperator(BaseOperator):
+class DropTableOperator(AstroSQLBaseOperator):
     """Airflow Operator for dropping SQL tables."""
 
     template_fields = ("table",)
 
     def __init__(
         self,
-        table: Table,
+        table: BaseTable,
         task_id: str = "",
         **kwargs,
     ):
@@ -28,7 +28,7 @@ class DropTableOperator(BaseOperator):
             **kwargs,
         )
 
-    def execute(self, context: dict) -> Table:  # skipcq: PYL-W0613
+    def execute(self, context: Context) -> BaseTable:  # skipcq: PYL-W0613
         """Method run when the Airflow runner calls the operator."""
         database = create_database(self.table.conn_id)
         self.table = database.populate_table_metadata(self.table)
@@ -37,7 +37,7 @@ class DropTableOperator(BaseOperator):
 
 
 def drop_table(
-    table: Table,
+    table: BaseTable,
     **kwargs: Any,
 ) -> XComArg:
     """
